@@ -1,11 +1,11 @@
 let browserslist = require('browserslist')
-let { agents } = require('caniuse-lite')
+let { agents } = require('caniuse-lite/dist/unpacker/agents')
 let pico = require('picocolors')
 
-let Browsers = require('./browsers')
-let Prefixes = require('./prefixes')
 let dataPrefixes = require('../data/prefixes')
+let Browsers = require('./browsers')
 let getInfo = require('./info')
+let Prefixes = require('./prefixes')
 
 let autoprefixerData = { browsers: agents, prefixes: dataPrefixes }
 
@@ -96,9 +96,9 @@ function plugin(...reqs) {
   }
 
   let brwlstOpts = {
+    env: options.env,
     ignoreUnknownVersions: options.ignoreUnknownVersions,
-    stats: options.stats,
-    env: options.env
+    stats: options.stats
   }
 
   function loadPrefixes(opts) {
@@ -114,12 +114,21 @@ function plugin(...reqs) {
   }
 
   return {
-    postcssPlugin: 'autoprefixer',
+    browsers: reqs,
 
+    info(opts) {
+      opts = opts || {}
+      opts.from = opts.from || process.cwd()
+      return getInfo(loadPrefixes(opts))
+    },
+
+    options,
+
+    postcssPlugin: 'autoprefixer',
     prepare(result) {
       let prefixes = loadPrefixes({
-        from: result.opts.from,
-        env: options.env
+        env: options.env,
+        from: result.opts.from
       })
 
       return {
@@ -133,16 +142,7 @@ function plugin(...reqs) {
           }
         }
       }
-    },
-
-    info(opts) {
-      opts = opts || {}
-      opts.from = opts.from || process.cwd()
-      return getInfo(loadPrefixes(opts))
-    },
-
-    options,
-    browsers: reqs
+    }
   }
 }
 
