@@ -1,7 +1,14 @@
-let flexSpec = require('./flex-spec')
 let Declaration = require('../declaration')
+let flexSpec = require('./flex-spec')
 
 class AlignContent extends Declaration {
+  /**
+   * Return property name by final spec
+   */
+  normalize() {
+    return 'align-content'
+  }
+
   /**
    * Change property name for 2012 spec
    */
@@ -14,13 +21,6 @@ class AlignContent extends Declaration {
     return super.prefixed(prop, prefix)
   }
 
-  /**
-   * Return property name by final spec
-   */
-  normalize() {
-    return 'align-content'
-  }
-
   /**
    * Change value for 2012 spec and ignore prefix for 2009
    */
@@ -42,8 +42,8 @@ AlignContent.names = ['align-content', 'flex-line-pack']
 AlignContent.oldValues = {
   'flex-end': 'end',
   'flex-start': 'start',
-  'space-between': 'justify',
-  'space-around': 'distribute'
+  'space-around': 'distribute',
+  'space-between': 'justify'
 }
 
 module.exports = AlignContent
