@@ -73,9 +73,9 @@ MaskComposite.names = ['mask', 'mask-composite']
 
 MaskComposite.oldValues = {
   add: 'source-over',
-  subtract: 'source-out',
+  exclude: 'xor',
   intersect: 'source-in',
-  exclude: 'xor'
+  subtract: 'source-out'
 }
 
 MaskComposite.regexp = new RegExp(
