@@ -94,11 +94,6 @@ class Processor {
         return displayGrid || gridTemplate || gridGap
       })
     }
-    function insideFlex(decl) {
-      return decl.parent.some(node => {
-        return node.prop === 'display' && /(inline-)?flex/.test(node.value)
-      })
-    }
 
     let gridPrefixes =
       this.gridStatus(css, result) &&
@@ -113,11 +108,13 @@ class Processor {
       let value = decl.value
 
       if (prop === 'color-adjust') {
-        result.warn(
-          'Replace color-adjust to print-color-adjust. ' +
-            'The color-adjust shorthand is currently deprecated.',
-          { node: decl }
-        )
+        if (parent.every(i => i.prop !== 'print-color-adjust')) {
+          result.warn(
+            'Replace color-adjust to print-color-adjust. ' +
+              'The color-adjust shorthand is currently deprecated.',
+            { node: decl }
+          )
+        }
       } else if (prop === 'grid-row-span') {
         result.warn(
           'grid-row-span is not part of final Grid Layout. Use grid-row.',
@@ -145,17 +142,6 @@ class Processor {
             { node: decl }
           )
         }
-      } else if (
-        /^(align|justify|place)-(items|content)$/.test(prop) &&
-        insideFlex(decl)
-      ) {
-        if (value === 'start' || value === 'end') {
-          result.warn(
-            `${value} value has mixed support, consider using ` +
-              `flex-${value} instead`,
-            { node: decl }
-          )
-        }
       } else if (prop === 'text-decoration-skip' && value === 'ink') {
         result.warn(
           'Replace text-decoration-skip: ink to ' +
@@ -394,141 +380,6 @@ class Processor {
     })
   }
 
-  /**
-   * Remove unnecessary pefixes
-   */
-  remove(css, result) {
-    // At-rules
-    let resolution = this.prefixes.remove['@resolution']
-
-    css.walkAtRules((rule, i) => {
-      if (this.prefixes.remove[`@${rule.name}`]) {
-        if (!this.disabled(rule, result)) {
-          rule.parent.removeChild(i)
-        }
-      } else if (
-        rule.name === 'media' &&
-        rule.params.includes('-resolution') &&
-        resolution
-      ) {
-        resolution.clean(rule)
-      }
-    })
-
-    // Selectors
-    for (let checker of this.prefixes.remove.selectors) {
-      css.walkRules((rule, i) => {
-        if (checker.check(rule)) {
-          if (!this.disabled(rule, result)) {
-            rule.parent.removeChild(i)
-          }
-        }
-      })
-    }
-
-    return css.walkDecls((decl, i) => {
-      if (this.disabled(decl, result)) return
-
-      let rule = decl.parent
-      let unprefixed = this.prefixes.unprefixed(decl.prop)
-
-      // Transition
-      if (decl.prop === 'transition' || decl.prop === 'transition-property') {
-        this.prefixes.transition.remove(decl)
-      }
-
-      // Properties
-      if (
-        this.prefixes.remove[decl.prop] &&
-        this.prefixes.remove[decl.prop].remove
-      ) {
-        let notHack = this.prefixes.group(decl).down(other => {
-          return this.prefixes.normalize(other.prop) === unprefixed
-        })
-
-        if (unprefixed === 'flex-flow') {
-          notHack = true
-        }
-
-        if (decl.prop === '-webkit-box-orient') {
-          let hacks = { 'flex-direction': true, 'flex-flow': true }
-          if (!decl.parent.some(j => hacks[j.prop])) return
-        }
-
-        if (notHack && !this.withHackValue(decl)) {
-          if (decl.raw('before').includes('\n')) {
-            this.reduceSpaces(decl)
-          }
-          rule.removeChild(i)
-          return
-        }
-      }
-
-      // Values
-      for (let checker of this.prefixes.values('remove', unprefixed)) {
-        if (!checker.check) continue
-        if (!checker.check(decl.value)) continue
-
-        unprefixed = checker.unprefixed
-        let notHack = this.prefixes.group(decl).down(other => {
-          return other.value.includes(unprefixed)
-        })
-
-        if (notHack) {
-          rule.removeChild(i)
-          return
-        }
-      }
-    })
-  }
-
-  /**
-   * Some rare old values, which is not in standard
-   */
-  withHackValue(decl) {
-    return decl.prop === '-webkit-background-clip' && decl.value === 'text'
-  }
-
-  /**
-   * Check for grid/flexbox options.
-   */
-  disabledValue(node, result) {
-    if (this.gridStatus(node, result) === false && node.type === 'decl') {
-      if (node.prop === 'display' && node.value.includes('grid')) {
-        return true
-      }
-    }
-    if (this.prefixes.options.flexbox === false && node.type === 'decl') {
-      if (node.prop === 'display' && node.value.includes('flex')) {
-        return true
-      }
-    }
-    if (node.type === 'decl' && node.prop === 'content') {
-      return true
-    }
-
-    return this.disabled(node, result)
-  }
-
-  /**
-   * Check for grid/flexbox options.
-   */
-  disabledDecl(node, result) {
-    if (this.gridStatus(node, result) === false && node.type === 'decl') {
-      if (node.prop.includes('grid') || node.prop === 'justify-items') {
-        return true
-      }
-    }
-    if (this.prefixes.options.flexbox === false && node.type === 'decl') {
-      let other = ['order', 'justify-content', 'align-items', 'align-content']
-      if (node.prop.includes('flex') || other.includes(node.prop)) {
-        return true
-      }
-    }
-
-    return this.disabled(node, result)
-  }
-
   /**
    * Check for control comment and global options
    */
@@ -588,35 +439,43 @@ class Processor {
   }
 
   /**
-   * Normalize spaces in cascade declaration group
+   * Check for grid/flexbox options.
    */
-  reduceSpaces(decl) {
-    let stop = false
-    this.prefixes.group(decl).up(() => {
-      stop = true
-      return true
-    })
-    if (stop) {
-      return
+  disabledDecl(node, result) {
+    if (node.type === 'decl' && this.gridStatus(node, result) === false) {
+      if (node.prop.includes('grid') || node.prop === 'justify-items') {
+        return true
+      }
+    }
+    if (node.type === 'decl' && this.prefixes.options.flexbox === false) {
+      let other = ['order', 'justify-content', 'align-items', 'align-content']
+      if (node.prop.includes('flex') || other.includes(node.prop)) {
+        return true
+      }
     }
 
-    let parts = decl.raw('before').split('\n')
-    let prevMin = parts[parts.length - 1].length
-    let diff = false
+    return this.disabled(node, result)
+  }
 
-    this.prefixes.group(decl).down(other => {
-      parts = other.raw('before').split('\n')
-      let last = parts.length - 1
-
-      if (parts[last].length > prevMin) {
-        if (diff === false) {
-          diff = parts[last].length - prevMin
-        }
-
-        parts[last] = parts[last].slice(0, -diff)
-        other.raws.before = parts.join('\n')
+  /**
+   * Check for grid/flexbox options.
+   */
+  disabledValue(node, result) {
+    if (this.gridStatus(node, result) === false && node.type === 'decl') {
+      if (node.prop === 'display' && node.value.includes('grid')) {
+        return true
       }
-    })
+    }
+    if (this.prefixes.options.flexbox === false && node.type === 'decl') {
+      if (node.prop === 'display' && node.value.includes('flex')) {
+        return true
+      }
+    }
+    if (node.type === 'decl' && node.prop === 'content') {
+      return true
+    }
+
+    return this.disabled(node, result)
   }
 
   /**
@@ -711,6 +570,140 @@ class Processor {
     node._autoprefixerGridStatus = value
     return value
   }
+
+  /**
+   * Normalize spaces in cascade declaration group
+   */
+  reduceSpaces(decl) {
+    let stop = false
+    this.prefixes.group(decl).up(() => {
+      stop = true
+      return true
+    })
+    if (stop) {
+      return
+    }
+
+    let parts = decl.raw('before').split('\n')
+    let prevMin = parts[parts.length - 1].length
+    let diff = false
+
+    this.prefixes.group(decl).down(other => {
+      parts = other.raw('before').split('\n')
+      let last = parts.length - 1
+
+      if (parts[last].length > prevMin) {
+        if (diff === false) {
+          diff = parts[last].length - prevMin
+        }
+
+        parts[last] = parts[last].slice(0, -diff)
+        other.raws.before = parts.join('\n')
+      }
+    })
+  }
+
+  /**
+   * Remove unnecessary pefixes
+   */
+  remove(css, result) {
+    // At-rules
+    let resolution = this.prefixes.remove['@resolution']
+
+    css.walkAtRules((rule, i) => {
+      if (this.prefixes.remove[`@${rule.name}`]) {
+        if (!this.disabled(rule, result)) {
+          rule.parent.removeChild(i)
+        }
+      } else if (
+        rule.name === 'media' &&
+        rule.params.includes('-resolution') &&
+        resolution
+      ) {
+        resolution.clean(rule)
+      }
+    })
+
+    // Selectors
+    css.walkRules((rule, i) => {
+      if (this.disabled(rule, result)) return
+
+      for (let checker of this.prefixes.remove.selectors) {
+        if (checker.check(rule)) {
+          rule.parent.removeChild(i)
+          return
+        }
+      }
+    })
+
+    return css.walkDecls((decl, i) => {
+      if (this.disabled(decl, result)) return
+
+      let rule = decl.parent
+      let unprefixed = this.prefixes.unprefixed(decl.prop)
+
+      // Transition
+      if (decl.prop === 'transition' || decl.prop === 'transition-property') {
+        this.prefixes.transition.remove(decl)
+      }
+
+      // Properties
+      if (
+        this.prefixes.remove[decl.prop] &&
+        this.prefixes.remove[decl.prop].remove
+      ) {
+        let notHack = this.prefixes.group(decl).down(other => {
+          return this.prefixes.normalize(other.prop) === unprefixed
+        })
+
+        if (unprefixed === 'flex-flow') {
+          notHack = true
+        }
+
+        if (decl.prop === '-webkit-box-orient') {
+          let hacks = { 'flex-direction': true, 'flex-flow': true }
+          if (!decl.parent.some(j => hacks[j.prop])) return
+        }
+
+        if (notHack && !this.withHackValue(decl)) {
+          if (decl.raw('before').includes('\n')) {
+            this.reduceSpaces(decl)
+          }
+          rule.removeChild(i)
+          return
+        }
+      }
+
+      // Values
+      for (let checker of this.prefixes.values('remove', unprefixed)) {
+        if (!checker.check) continue
+        if (!checker.check(decl.value)) continue
+
+        unprefixed = checker.unprefixed
+        let notHack = this.prefixes.group(decl).down(other => {
+          return other.value.includes(unprefixed)
+        })
+
+        if (notHack) {
+          rule.removeChild(i)
+          return
+        }
+      }
+    })
+  }
+
+  /**
+   * Some rare old values, which is not in standard
+   */
+  withHackValue(decl) {
+    return (
+      (decl.prop === '-webkit-background-clip' && decl.value === 'text') ||
+      // Do not remove -webkit-box-orient when -webkit-line-clamp is present.
+      // https://github.com/postcss/autoprefixer/issues/1510
+      (decl.prop === '-webkit-box-orient' &&
+        decl.parent.some(d => d.prop === '-webkit-line-clamp'))
+    )
+  }
 }
 
 module.exports = Processor
