@@ -1,16 +1,16 @@
-let { equal, throws, type, match, not } = require('uvu/assert')
-let { restoreAll, spyOn } = require('nanospy')
 let { readFileSync } = require('fs')
+let { restoreAll, spyOn } = require('nanospy')
 let { join } = require('path')
-let { test } = require('uvu')
 let postcss = require('postcss')
+let { test } = require('uvu')
+let { equal, match, not, throws, type } = require('uvu/assert')
 
 let autoprefixer = require('..')
 
 let grider = autoprefixer({
-  overrideBrowserslist: ['Chrome 25', 'Edge 12', 'IE 10'],
   cascade: false,
-  grid: 'autoplace'
+  grid: 'autoplace',
+  overrideBrowserslist: ['Chrome 25', 'Edge 12', 'IE 10']
 })
 
 let cleaner = autoprefixer({
@@ -26,8 +26,8 @@ let borderer = autoprefixer({
   overrideBrowserslist: ['Safari 4', 'Firefox 3.6']
 })
 let cascader = autoprefixer({
-  overrideBrowserslist: ['Chrome > 19', 'Firefox 21', 'IE 10'],
-  cascade: true
+  cascade: true,
+  overrideBrowserslist: ['Chrome > 19', 'Firefox 21', 'IE 10']
 })
 let keyframer = autoprefixer({
   overrideBrowserslist: ['Chrome > 19', 'Opera 12']
@@ -48,8 +48,8 @@ let gradienter = autoprefixer({
   overrideBrowserslist: ['Chrome 25', 'Opera 12', 'Android 2.3']
 })
 let grouping = autoprefixer({
-  overrideBrowserslist: ['Chrome 25', 'Firefox > 17', 'IE 10', 'Edge 12'],
-  grid: 'autoplace'
+  grid: 'autoplace',
+  overrideBrowserslist: ['Chrome 25', 'Firefox > 17', 'IE 10', 'Edge 12']
 })
 let ffgradienter = autoprefixer({
   overrideBrowserslist: ['Chrome 25', 'Opera 12', 'Firefox 6']
@@ -60,6 +60,9 @@ let selectorer = autoprefixer({
 let fileSelectorButtoner = autoprefixer({
   overrideBrowserslist: ['Chrome > 25', 'Firefox >= 82']
 })
+let backdroper = autoprefixer({
+  overrideBrowserslist: ['IE >= 11', 'Chrome < 32', 'Safari >= 15.4']
+})
 let placeholderShowner = autoprefixer({
   overrideBrowserslist: ['IE >= 10']
 })
@@ -90,6 +93,9 @@ let example = autoprefixer({
 let autofiller = autoprefixer({
   overrideBrowserslist: ['Chrome > 90', 'Firefox >= 82']
 })
+let textDecorator = autoprefixer({
+  overrideBrowserslist: ['Chrome >= 57', 'Firefox >= 36', 'Safari >= 12.1']
+})
 let content = autoprefixer({
   overrideBrowserslist: [
     '> 2%',
@@ -137,10 +143,14 @@ function prefixer(name) {
     name === 'at-rules'
   ) {
     return intrinsicer
+  } else if (name === 'text-decoration-shorthand') {
+    return textDecorator
   } else if (name === 'selectors' || name === 'placeholder') {
     return selectorer
   } else if (name === 'selectors' || name === 'file-selector-button') {
     return fileSelectorButtoner
+  } else if (name === 'selectors' || name === 'backdrop') {
+    return backdroper
   } else if (
     name === 'selectors' ||
     name === 'autofill' ||
@@ -527,8 +537,8 @@ test('does not remove unnecessary prefixes on request', () => {
 test('does not add prefixes on request', () => {
   for (let i of ['transition', 'values', 'fullscreen']) {
     let remover = autoprefixer({
-      overrideBrowserslist: ['Opera 12'],
-      add: false
+      add: false,
+      overrideBrowserslist: ['Opera 12']
     })
     let unprefixed = read(i)
     equal(postcss([remover]).process(unprefixed).css, unprefixed)
@@ -628,8 +638,8 @@ test('has disabled grid options by default', () => {
 test('has different outputs for different grid options', () => {
   function ap(gridValue) {
     return autoprefixer({
-      overrideBrowserslist: ['Edge 12', 'IE 10'],
-      grid: gridValue
+      grid: gridValue,
+      overrideBrowserslist: ['Edge 12', 'IE 10']
     })
   }
   let input = read('grid-options')
@@ -671,8 +681,8 @@ test('has different outputs for different grid environment variables', () => {
 test('has option to disable flexbox support', () => {
   let css = read('flexbox')
   let instance = autoprefixer({
-    overrideBrowserslist: ['IE 10'],
-    flexbox: false
+    flexbox: false,
+    overrideBrowserslist: ['IE 10']
   })
   let result = postcss([instance]).process(css)
   equal(result.css, css)
@@ -680,8 +690,8 @@ test('has option to disable flexbox support', () => {
 
 test('has option to disable 2009 flexbox support', () => {
   let ap = autoprefixer({
-    overrideBrowserslist: ['Chrome > 19'],
-    flexbox: 'no-2009'
+    flexbox: 'no-2009',
+    overrideBrowserslist: ['Chrome > 19']
   })
   let css = 'a{flex:1;transition:flex}'
   let result = postcss([ap]).process(css)
@@ -713,8 +723,8 @@ test('ignores unknown versions on request', () => {
   }, /Unknown version 100 of ie/)
   not.throws(() => {
     autoprefixer({
-      overrideBrowserslist: ['ie 100'],
-      ignoreUnknownVersions: true
+      ignoreUnknownVersions: true,
+      overrideBrowserslist: ['ie 100']
     }).info()
   })
 })
@@ -755,6 +765,10 @@ test('supports file-selector-button', () => {
   check('file-selector-button')
 })
 
+test('supports ::backdrop', () => {
+  check('backdrop')
+})
+
 test('supports custom prefixes', () => {
   check('custom-prefix')
 })
@@ -889,25 +903,6 @@ test('warns on old flexbox display', () => {
   )
 })
 
-test('warns on mixed support usage', () => {
-  let css = 'a { display: flex; align-content: start; justify-content: end; }'
-  let result = postcss([
-    autoprefixer({
-      overrideBrowserslist: ['IE 11']
-    })
-  ]).process(css)
-  equal(result.css, css)
-  equal(
-    result.warnings().map(i => i.toString()),
-    [
-      'autoprefixer: <css input>:1:20: start value has mixed support, ' +
-        'consider using flex-start instead',
-      'autoprefixer: <css input>:1:42: end value has mixed support, ' +
-        'consider using flex-end instead'
-    ]
-  )
-})
-
 test('supports intrinsic sizing', () => {
   let input = read('intrinsic')
   let output = read('intrinsic.out')
@@ -1040,8 +1035,8 @@ test('supports grid autoplacement', () => {
 test('shows Grid warnings only for IE', () => {
   let input = 'a { grid-template-rows: repeat(auto-fit, 1px) }'
   let instance = autoprefixer({
-    overrideBrowserslist: 'chrome 27',
-    grid: true
+    grid: true,
+    overrideBrowserslist: 'chrome 27'
   })
   let result = postcss([instance]).process(input)
   equal(result.warnings().length, 0)
@@ -1125,8 +1120,8 @@ test('add prefix for backface-visibility for Safari 9', () => {
   let input =
     'a{ ' + 'backface-visibility: hidden; ' + 'transform-style: preserve-3d }'
   let ap = autoprefixer({
-    overrideBrowserslist: ['Safari 9'],
-    flexbox: false
+    flexbox: false,
+    overrideBrowserslist: ['Safari 9']
   })
   equal(
     postcss([ap]).process(input).css,
@@ -1139,21 +1134,35 @@ test('add prefix for backface-visibility for Safari 9', () => {
 
 test('supports text-decoration', () => {
   let input = read('text-decoration')
+  let output = read('text-decoration.out')
   let instance = prefixer('text-decoration')
   let result = postcss([instance]).process(input)
+
+  equal(universalizer(result.css), universalizer(output))
   equal(
     result.warnings().map(i => i.toString()),
     [
-      'autoprefixer: <css input>:26:3: Replace text-decoration-skip: ink ' +
+      'autoprefixer: <css input>:32:3: Replace text-decoration-skip: ink ' +
         'to text-decoration-skip-ink: auto, because spec had been changed'
     ]
   )
 })
 
+test('supports text-decoration shorthand', () => {
+  let input = read('text-decoration')
+  let output = read('text-decoration.shorthand.out')
+  let instance = prefixer('text-decoration-shorthand')
+  let result = postcss([instance]).process(input)
+
+  equal(universalizer(result.css), universalizer(output))
+})
+
 test('supports -webkit-line-clamp', () => {
   let input = read('webkit-line-clamp')
+  let output = read('webkit-line-clamp.out')
   let result = postcss([cleaner]).process(input)
-  equal(result.css, input)
+
+  equal(universalizer(result.css), universalizer(output))
   equal(result.warnings().length, 0)
 })
 
